@@ -40,7 +40,7 @@ sub new {
 	LIST  => [],
 	COUNT => [],
     }, $class;
-    configure $obj @_ if @_;
+    $obj->configure(@_) if @_;
     $obj;
 }
 
